@@ -13,7 +13,7 @@ module YARD
       # @return [Hash] a list of library names and yardoc files to serve
       attr_accessor :libraries
 
-      # @return [Adapter] the adapter to use for loading the web server
+      # @return [YARD::Server::Adapter] the adapter to use for loading the web server
       attr_accessor :adapter
 
       # @return [Array<String>] a list of scripts to load
@@ -127,7 +127,7 @@ module YARD
 
       def add_gems
         require 'rubygems'
-        YARD::GemIndex.find_all_by_name('').each do |spec|
+        YARD::GemIndex.each do |spec|
           libraries[spec.name] ||= []
           libraries[spec.name] |= [YARD::Server::LibraryVersion.new(spec.name, spec.version.to_s, nil, :gem)]
         end
