@@ -1,12 +1,16 @@
+# frozen_string_literal: true
 # @group Global Convenience Methods
 
 # Shortcut for creating a YARD::CodeObjects::Proxy via a path
 #
 # @see YARD::CodeObjects::Proxy
 # @see YARD::Registry.resolve
-def P(namespace, name = nil)
-  namespace, name = nil, namespace if name.nil?
-  YARD::Registry.resolve(namespace, name, false, true)
+def P(namespace, name = nil, type = nil) # rubocop:disable Style/MethodName
+  if name.nil?
+    name = namespace
+    namespace = nil
+  end
+  YARD::Registry.resolve(namespace, name, false, true, type)
 end
 
 # The global {YARD::Logger} instance
