@@ -1,6 +1,8 @@
 # frozen_string_literal: true
 # Handles a method definition
 class YARD::Handlers::Ruby::MethodHandler < YARD::Handlers::Ruby::Base
+  include YARD::Handlers::Common::MethodHandler
+
   handles :def, :defs
 
   process do
@@ -19,7 +21,6 @@ class YARD::Handlers::Ruby::MethodHandler < YARD::Handlers::Ruby::Base
 
     nobj = P(namespace, nobj.value) while nobj.type == :constant
     obj = register MethodObject.new(nobj, meth, mscope) do |o|
-      o.signature = method_signature
       o.explicit = true
       o.parameters = args
     end
@@ -39,13 +40,7 @@ class YARD::Handlers::Ruby::MethodHandler < YARD::Handlers::Ruby::Base
         extended method_added method_removed method_undefined).include?(meth)
       obj.add_tag(YARD::Tags::Tag.new(:private, nil))
     elsif meth.to_s =~ /\?$/
-      if obj.tag(:return) && (obj.tag(:return).types || []).empty?
-        obj.tag(:return).types = ['Boolean']
-      elsif obj.tag(:return).nil?
-        unless obj.tags(:overload).any? {|overload| overload.tag(:return) }
-          obj.add_tag(YARD::Tags::Tag.new(:return, "", "Boolean"))
-        end
-      end
+      add_predicate_return_tag(obj)
     end
 
     if obj.has_tag?(:option)
@@ -106,13 +101,4 @@ class YARD::Handlers::Ruby::MethodHandler < YARD::Handlers::Ruby::Base
 
     params
   end
-
-  def method_signature
-    method_name = statement.method_name(true)
-    if statement.parameters.any? {|e| e }
-      "def #{method_name}(#{statement.parameters.source})"
-    else
-      "def #{method_name}"
-    end
-  end
 end
