@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 # Handles the 'include' statement to mixin a module in the instance scope
 class YARD::Handlers::Ruby::MixinHandler < YARD::Handlers::Ruby::Base
   handles method_call(:include)
@@ -12,7 +13,7 @@ class YARD::Handlers::Ruby::MixinHandler < YARD::Handlers::Ruby::Base
         errors << err.message
       end
     end
-    if errors.size > 0
+    unless errors.empty?
       msg = errors.size == 1 ? ": #{errors[0]}" : "s: #{errors.join(", ")}"
       raise YARD::Parser::UndocumentableError, "mixin#{msg} for class #{namespace.path}"
     end
@@ -31,6 +32,18 @@ class YARD::Handlers::Ruby::MixinHandler < YARD::Handlers::Ruby::Base
       obj = Proxy.new(namespace, mixin.source, :module)
     end
 
-    namespace.mixins(scope).unshift(obj) unless namespace.mixins(scope).include?(obj)
+    rec = recipient(mixin)
+    return if rec.nil? || rec.mixins(scope).include?(obj)
+    rec.mixins(scope).unshift(obj)
+  end
+
+  def recipient(mixin)
+    if statement[0].type == :var_ref && statement[0][0] != s(:kw, "self")
+      statement[0][0].type == :const ?
+        Proxy.new(namespace, statement.namespace.source) :
+        nil
+    else
+      namespace
+    end
   end
 end
