@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 require 'fileutils'
 
 module YARD
@@ -19,6 +20,7 @@ module YARD
       @notfound = {}
       @loaded_objects = 0
       @available_objects = 0
+      @locales = {}
       @store[:root] = CodeObjects::RootObject.allocate
       @store[:root].send(:initialize, nil, :root)
     end
@@ -36,7 +38,8 @@ module YARD
 
       # check disk
       return if @notfound[key]
-      if obj = @serializer.deserialize(key)
+      obj = @serializer.deserialize(key)
+      if obj
         @loaded_objects += 1
         put(key, obj)
       else
@@ -69,7 +72,12 @@ module YARD
     # Deletes an object at a given path
     # @param [#to_sym] key the key to delete
     # @return [void]
-    def delete(key) @store.delete(key.to_sym) end
+    def delete(key)
+      if @store[key.to_sym]
+        @object_types[@store[key.to_sym].type].delete(key.to_s)
+        @store.delete(key.to_sym)
+      end
+    end
 
     # Gets all path names from the store. Loads the entire database
     # if +reload+ is +true+
@@ -108,14 +116,18 @@ module YARD
     # @return [CodeObjects::RootObject] the root object
     def root; @store[:root] end
 
+    # @param [String] name the locale name.
+    # @return [I18n::Locale] the locale object for +name+.
+    # @since 0.8.3
+    def locale(name)
+      @locales[name] ||= load_locale(name)
+    end
+
     # @param [String, nil] file the name of the yardoc db to load
     # @return [Boolean] whether the database was loaded
     def load(file = nil)
+      initialize
       @file = file
-      @store = {}
-      @proxy_types = {}
-      @object_types = {}
-      @notfound = {}
       @serializer = Serializers::YardocSerializer.new(@file)
       load_yardoc
     end
@@ -144,14 +156,15 @@ module YARD
       log.debug "Loading entire database: #{@file} ..."
       objects = []
 
-      all_disk_objects.sort_by {|x| x.size }.each do |path|
-        if obj = @serializer.deserialize(path, true)
-          objects << obj
-        end
+      all_disk_objects.sort_by(&:size).each do |path|
+        obj = @serializer.deserialize(path, true)
+        objects << obj if obj
       end
+
       objects.each do |obj|
         put(obj.path, obj)
       end
+
       @loaded_objects += objects.size
       log.debug "Loaded database (file='#{@file}' count=#{objects.size} total=#{@available_objects})"
     end
@@ -169,7 +182,7 @@ module YARD
       destroy unless merge
 
       sdb = Registry.single_object_db
-      if sdb == true || sdb == nil
+      if sdb == true || sdb.nil?
         @serializer.serialize(@store)
       else
         values(false).each do |object|
@@ -179,9 +192,22 @@ module YARD
       write_proxy_types
       write_object_types
       write_checksums
+      write_complete_lock
       true
     end
 
+    # (see Serializers::YardocSerializer#lock_for_writing)
+    # @param file [String] if supplied, the path to the database
+    def lock_for_writing(file = nil, &block)
+      Serializers::YardocSerializer.new(file || @file).lock_for_writing(&block)
+    end
+
+    # (see Serializers::YardocSerializer#locked_for_writing?)
+    # @param file [String] if supplied, the path to the database
+    def locked_for_writing?(file = nil)
+      Serializers::YardocSerializer.new(file || @file).locked_for_writing?
+    end
+
     # Deletes the .yardoc database on disk
     #
     # @param [Boolean] force if force is not set to true, the file/directory
@@ -271,18 +297,25 @@ module YARD
     end
 
     def load_root
-      if root = @serializer.deserialize('root')
-        @loaded_objects += 1
-        if root.is_a?(Hash) # single object db
-          log.debug "Loading single object DB from .yardoc"
-          @loaded_objects += (root.keys.size - 1)
-          @store = root
-        else # just the root object
-          @store[:root] = root
-        end
+      root = @serializer.deserialize('root')
+      return if root.nil?
+
+      @loaded_objects += 1
+      if root.is_a?(Hash) # single object db
+        log.debug "Loading single object DB from .yardoc"
+        @loaded_objects += (root.keys.size - 1)
+        @store = root
+      else # just the root object
+        @store[:root] = root
       end
     end
 
+    def load_locale(name)
+      locale = I18n::Locale.new(name)
+      locale.load(Registry.po_dir)
+      locale
+    end
+
     def all_disk_objects
       Dir.glob(File.join(objects_path, '**/*')).select {|f| File.file?(f) }
     end
@@ -301,5 +334,9 @@ module YARD
         @checksums.each {|k, v| f.puts("#{k} #{v}") }
       end
     end
+
+    def write_complete_lock
+      File.open!(@serializer.complete_lock_path, 'w') {}
+    end
   end
-end
\ No newline at end of file
+end
