@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 module YARD
   module Serializers
     # A serializer that writes data to standard output.
@@ -11,7 +12,7 @@ module YARD
       end
 
       # Overrides serialize behaviour to write data to standard output
-      def serialize(object, data)
+      def serialize(_object, data)
         print(@wrap ? word_wrap(data, @wrap) : data)
       end
 
@@ -20,13 +21,14 @@ module YARD
       # Wraps text to a specific column length
       #
       # @param [String] text the text to wrap
-      # @param [Fixnum] length the column length to wrap to
+      # @param [Fixnum] _length the column length to wrap to
       # @return [String] the wrapped text
-      def word_wrap(text, length = 80)
+      def word_wrap(text, _length = 80)
         # See ruby-talk/10655 / Ernest Ellingson
-        text.gsub(/\t/,"     ").gsub(/.{1,50}(?:\s|\Z)/){($& +
-          5.chr).gsub(/\n\005/,"\n").gsub(/\005/,"\n")}
+        text.gsub(/\t/, "     ").gsub(/.{1,50}(?:\s|\Z)/) do
+          ($& + 5.chr).gsub(/\n\005/, "\n").gsub(/\005/, "\n")
+        end
       end
     end
   end
-end
\ No newline at end of file
+end
