@@ -24,6 +24,39 @@ RSpec.describe YARD::Parser::C::CParser do
         expect(obj.docstring).not_to be_blank
         expect(obj.tags(:overload).size).to be > 1
       end
+
+      it "parses new_ary return type" do
+        obj = YARD::Registry.at('Array#map')
+        expect(obj.tags(:overload).count do |overload|
+          overload.tag(:return) && overload.tag(:return).types == ['Enumerator']
+        end).to eq 2
+        expect(obj.tags(:overload).count do |overload|
+          overload.tag(:return) && overload.tag(:return).types == ['Array']
+        end).to eq 2
+      end
+    end
+
+    describe "C++ namespace" do
+      before(:all) do
+        file = File.join(File.dirname(__FILE__), 'examples', 'namespace.cpp.txt')
+        parse(File.read(file))
+      end
+
+      it "parses Rect class" do
+        obj = YARD::Registry.at('Rect')
+        expect(obj).not_to be nil
+        expect(obj.docstring).not_to be_blank
+      end
+
+      it "parses method inside of namespace" do
+        obj = YARD::Registry.at('Rect#inspect')
+        expect(obj.docstring).not_to be_blank
+      end
+
+      it "parses method after namespace" do
+        obj = YARD::Registry.at('Rect#hello_world')
+        expect(obj.docstring).not_to be_blank
+      end
     end
 
     describe "Source located in extra files" do
@@ -145,6 +178,19 @@ RSpec.describe YARD::Parser::C::CParser do
         expect(Registry.at('Foo#func').docstring).to eq "docstring"
       end
     end
+
+    describe "File singleton methods" do
+      before(:all) do
+        file = File.join(File.dirname(__FILE__), 'examples', 'file.c.txt')
+        parse(File.read(file))
+      end
+
+      it "parses methods from define_filetest_function" do
+        obj = YARD::Registry.at('File.exist?')
+        expect(obj).not_to be nil
+        expect(obj.docstring).not_to be_blank
+      end
+    end
   end
 
   describe "Override comments" do
