@@ -106,16 +106,6 @@ RSpec.describe YARD::Templates::Helpers::HtmlHelper do
   end
 
   describe "#htmlify" do
-    it "does not use hard breaks for textile markup (RedCloth specific)" do
-      begin; require 'redcloth'; rescue LoadError; pending 'test requires redcloth gem' end
-      expect(htmlify("A\nB", :textile)).not_to include("<br")
-    end
-
-    it "uses hard breaks for textile_strict markup (RedCloth specific)" do
-      begin; require 'redcloth'; rescue LoadError; pending 'test requires redcloth gem' end
-      expect(htmlify("A\nB", :textile_strict)).to include("<br")
-    end
-
     it "handles various encodings" do
       allow(self).to receive(:object).and_return(Registry.root)
       text = String.new("\xB0\xB1")
@@ -159,17 +149,6 @@ RSpec.describe YARD::Templates::Helpers::HtmlHelper do
       expect(htmlify("test {include:file:foo.rdoc}", :rdoc).gsub(/[\r?\n]+/, '')).to eq '<p>test HI</p>'
     end
 
-    it "autolinks URLs (markdown specific)" do
-      log.enter_level(Logger::FATAL) do
-        unless markup_class(:markdown).to_s == "RedcarpetCompat"
-          pending 'This test depends on a markdown engine that supports autolinking'
-        end
-      end
-      expect(htmlify('http://example.com', :markdown).chomp.gsub('&#47;', '/')).to eq(
-        '<p><a href="http://example.com">http://example.com</a></p>'
-      )
-    end
-
     it "does not autolink URLs inside of {} (markdown specific)" do
       log.enter_level(Logger::FATAL) do
         pending 'This test depends on markdown' unless markup_class(:markdown)
@@ -214,6 +193,40 @@ RSpec.describe YARD::Templates::Helpers::HtmlHelper do
       html = htmlify(markdown, :markdown)
       expect(html).to match %r{^<p>Introduction:</p>.*<code class="ruby">}m
     end
+
+    it "sets env and env-yard attributes (AsciiDoc specific)" do
+      adoc = <<-EOF.strip.gsub(/^ +/, "") # strip and unindent
+        ifdef::env[]
+        Attribute "env" is set, and its value is "{env}".
+        endif::[]
+
+        ifdef::env-yard[]
+        Attribute "env-yard" is set, and its value is "{env-yard}".
+        endif::[]
+      EOF
+      html = htmlify(adoc, :asciidoc)
+      expect(html).to match(/"env" is set, and its value is "yard"./)
+      expect(html).to match(/"env-yard" is set, and its value is ""./)
+    end
+
+    it "should not include the document title from the AsciiDoc header" do
+      adoc = <<-EOF.strip.gsub(/^ +/, "") # strip and unindent
+        = Project Name
+
+        Introduction.
+
+        == Installation
+
+        Installation instructions.
+
+        == Usage
+
+        Usage instructions.
+      EOF
+      html = htmlify(adoc, :asciidoc)
+      expect(html).to_not match(/Project Name/)
+      expect(html).to include(%(<h2 id="_installation">Installation</h2>))
+    end
   end
 
   describe "#link_object" do
